@@ -1,18 +1,15 @@
-
 #import "AAIMargin.h"
 
-
 @implementation AAIMargin
 
 + (instancetype)zero {
-    return [[self alloc] initWitht:@0 l:@0 b:@0 r:@0];;
+    return [[self alloc] initWitht:@0 l:@0 b:@0 r:@0];
 }
 
-- (instancetype)initWitht:(NSNumber * _Nullable)t
-                        l:(NSNumber * _Nullable)l
-                        b:(NSNumber * _Nullable)b
-                        r:(NSNumber * _Nullable)r {
-    
+- (instancetype)initWitht:(NSNumber* _Nullable)t
+                        l:(NSNumber* _Nullable)l
+                        b:(NSNumber* _Nullable)b
+                        r:(NSNumber* _Nullable)r {
     if (self = [super init]) {
         self.top = t;
         self.left = l;
@@ -22,29 +19,26 @@
     return self;
 }
 
-- (instancetype)initWithl:(NSNumber *)l 
-                        r:(NSNumber *)r {
-    
+- (instancetype)initWithl:(NSNumber*)l r:(NSNumber*)r {
     return [self initWitht:nil l:l b:nil r:r];
 }
 
 - (instancetype)standard {
-    
-    if (!self.top) {
+    if (self.top == nil) {
         self.top = @0;
     }
-    if (!self.left) {
+    if (self.left == nil) {
         self.left = @0;
     }
-    
-    if (!self.bottom) {
+
+    if (self.bottom == nil) {
         self.bottom = @0;
     }
-    
-    if (!self.right) {
+
+    if (self.right == nil) {
         self.right = @0;
     }
-    
+
     return self;
 }
 
